/*
A web-based forum application to show off the Niggle framework.
Copyright (c) 2001, Jonathan Revusky
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.

The name "Jonathan Revusky" may not be used to endorse or 
promote products derived from this software without specific prior 
written permission.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED 
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package com.revusky.forum.data;

import com.revusky.niggle.data.*;
import com.revusky.niggle.util.*;
import java.util.*;
import java.io.IOException;

/**
 * A single article in a web-based forum.
 * @author <A HREF="mailto:jon@revusky.com">Jonathan Revusky</A>
 */

public class Article extends DefaultRecord {


    public Article getParent() throws IOException {
        Object parentID = get("parent_id");
        if (parentID == null)
            return null;
        else
            return ForumUtil.getArticleByID(parentID);
    }

    public List getChildren() throws IOException {
        return ForumUtil.getChildren(this);
    }

    public Article getRoot() throws IOException {
        Article result = this;
        Article parent = result;
        while (parent != null) {
            result = parent;
            parent = parent.getParent();
        }
        return result;
    }

    public Record getAuthor() throws IOException {
        String authorID = (String) get("author_id");
        return ForumUtil.getUser(authorID);
    }


    public Forum getForum() throws IOException {
        return ForumUtil.getForum((String) get("forum_id"));
    }
}