/*
A web-based forum application to show off the Niggle framework.
Copyright (c) 2001, Jonathan Revusky
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.

The name "Jonathan Revusky" may not be used to endorse or 
promote products derived from this software without specific prior 
written permission.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED 
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package com.revusky.forum.templates;

import com.revusky.niggle.data.*;
import com.revusky.niggle.util.*;
import com.revusky.niggle.templates.freemarkerimpl.*;
import com.revusky.forum.data.*;
import java.util.*;
import java.io.IOException;
import freemarker.template.*;

/**
 * A display wrapper for an article.
 * @author <A HREF="mailto:jon@revusky.com">Jonathan Revusky</A>
 */

public class ArticleWrapper extends RecordWrapper {

    public TemplateModel get(String key) throws TemplateModelException {
        TemplateModel result = super.get(key);
        if (result != null)
            return result;
        if (CASE_INSENSITIVE) {
            key = key.toLowerCase();
        }
        Article article = (Article) rec;
        try {
            if (key.equals("numsubarticles")) {
                int num = ForumUtil.getNumSubArticles(article);
                result = createWrapper(String.valueOf(num));
            }
            else if (key.equals("mostrecent")) {
                Article mostRecent  = ForumUtil.getMostRecent(article);
                result = createWrapper(mostRecent);
            }
            else if (key.equals("firstline")) {
                result = createWrapper(firstLine());
            }
            else if (key.equals("url")) {
                String url = interaction.getURL("displayArticle") + "&article_id=" + article.getPrimaryKey();
                url = interaction.response.encodeURL(url);
                result = createWrapper(url);
            }
            else if (key.equals("replyurl")) {
                String url = interaction.getURL("reply") + "&article_id=" + article.getPrimaryKey();
                url = interaction.response.encodeURL(url);
                result = createWrapper(url);
            }
        }
        catch (IOException ioe) {
            Logger.logException(ioe);
            throw new TemplateModelException(ioe.getMessage());
        }
        put(key, result);
        return result;
    }

/*
    private String firstLine()  {
        String body = (String) rec.get("body");
        StringBuffer buf = new StringBuffer(80);
        StringTokenizer st = new StringTokenizer(body);
        while (st.hasMoreTokens()) {
            buf.append(st.nextToken());
            buf.append((char) ' ');
            if (buf.length() >60) 
                break;
        }
        if (st.hasMoreTokens()) {
            buf.append("...");
        }
        return buf.toString();
    }*/

    /**
     * Just gets the first line of the article for display purposes.
     */
        
    private String firstLine()  {
        String body = (String) rec.get("body");
        StringBuffer buf = new StringBuffer(80);
        StringTokenizer st = new StringTokenizer(body, " <>\t\n\r", true);
        while (st.hasMoreTokens()) {
            String tok = st.nextToken();
            if (tok.trim().length() == 0)
                tok = " ";
            if (tok.equals("<"))
                tok = "&LT;";
            else if (tok.equals(">")) 
                tok = "&GT;";
            buf.append(tok);
            if (buf.length() >60) 
                break;
        }
        if (st.hasMoreTokens()) {
            buf.append("...");
        }
        return buf.toString();
    }

}
